/*
** Module   : SessionSettings.java
** Abstract : configuration to establish a remote session 
**
** Copyright (c) 2008-2009, Golden Code Development Corporation.
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 GES 20081218 Stores configuration to establish a remote session.
*/

/*
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU Affero General Public License as
** published by the Free Software Foundation, either version 3 of the
** License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package com.goldencode.harness;

import com.goldencode.harness.transport.*;

/**
 * Stores configuration to establish a remote terminal session via TCP/IP.
 */
public class SessionSettings
{
   /** Host to which to connect. */
   public String host = "localhost";
   
   /** Port number for the socket. */
   public int port = 22;
   
   /** Account name. */
   public String userid = null;
   
   /** Account password. */
   public String password = null;
   
   /** Terminal type to emulate. */
   public String termType = "vt320";
   
   /** Number of columns (width) of the terminal. */
   public int termColumns = 80;
   
   /** Number of rows (height) of the terminal. */
   public int termRows = 24;
   
   /** Communication session protocol. */
   public TransportType protocol = TransportType.SSH2;
   
   /** List of field names for which an editing prompt should be forced. */
   public String prompts = null;
   
   /**
    * Default constructor.
    */
   public SessionSettings()
   {
   }
   
   /**
    * Copy constructor.
    *
    * @param    original
    *           Instance from which to copy.
    */
   public SessionSettings(SessionSettings original)
   {
      this.host        = original.host;
      this.port        = original.port;
      this.userid      = original.userid;
      this.password    = original.password;
      this.termType    = original.termType;
      this.termColumns = original.termColumns;
      this.termRows    = original.termRows;
      this.protocol    = original.protocol;
      this.prompts     = original.prompts;
   }
}
