/*
** Module   : AcquireMutexCleanup.java
** Abstract : releases a mutex at end of testing (if not already released)
**
** Copyright (c) 2009, Golden Code Development Corporation.
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 GES 20090224 Releases a mutex at end of testing (if not already
**                  released).
*/

/*
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU Affero General Public License as
** published by the Free Software Foundation, either version 3 of the
** License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package com.goldencode.harness.test;

import java.util.concurrent.locks.*;

/**
 * Releases a mutex at end of testing (if not already released).
 */
public class AcquireMutexCleanup
implements Cleanup
{
   /** The mutex to utilize. */
   private final ReentrantLock mutex;
   
   /**
    * Constructor.
    *
    * @param    mutex
    *           The mutex semaphore to use.
    */
   public AcquireMutexCleanup(ReentrantLock mutex)
   {
      this.mutex = mutex;
   }
   
   /**
    * Cleanup processing.
    */
   public void execute()
   {
      if (mutex.isHeldByCurrentThread())
      {
         int num = mutex.getHoldCount();
         
         for (int i = 0; i < num; i++)
         {
            mutex.unlock();
         }
      }
   }
}
