/*
** Module   : CheckVariable.java
** Abstract : directive to pass/fail based on a named boolean variable
**
** Copyright (c) 2009, Golden Code Development Corporation.
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 GES 20090126 Directive to pass/fail based on a named boolean variable.
*/

/*
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU Affero General Public License as
** published by the Free Software Foundation, either version 3 of the
** License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package com.goldencode.harness.test;

import com.goldencode.harness.*;
import com.goldencode.harness.terminal.*;

/**
 * Directive to pass/fail based on a named boolean variable.
 */
public class CheckVariable
extends Report
implements Testable
{
   /** Short name for the activity. */
   private static final String NAME = "CHECK-VARIABLE";
   
   /** Variable to test. */
   private Variable var = null;
   
   /**
    * Constructor.
    *
    * @param    var
    *           Variable to test.
    */
   public CheckVariable(Variable var)
   {
      super(NAME, "");
      this.var = var;
   }
   
   /**
    * Execute the directive of the test using the given terminal as the data
    * sink and/or source for the operation.
    *
    * @param    term
    *           The terminal that represents the system under test.
    */
   public void execute(Terminal term)
   {
      boolean result = var.asBoolean();
      
      setDescription(String.format("variable = %s; value = %b;",
                                   var.getName(),
                                   result));
      setStatus(result ? Status.PASSED : Status.FAILED, null);
   }
}
