/*
** Module   : Log.java
** Abstract : directive to store text in the results report
**
** Copyright (c) 2009, Golden Code Development Corporation.
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 GES 20090126 Directive to store text in the results report.
*/

/*
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU Affero General Public License as
** published by the Free Software Foundation, either version 3 of the
** License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package com.goldencode.harness.test;

import com.goldencode.harness.*;
import com.goldencode.harness.terminal.*;

/**
 * Directive to store text in the results report.
 */
public class Log
extends Report
implements Testable
{
   /** Short name for the activity. */
   private static final String NAME = "LOG";
   
   /** The text to store. */
   private final String text;
   
   /** Parameter substitutions. */
   private final Variable[] subs;
   
   /**
    * Constructor.
    *
    * @param    text
    *           The text to insert into the results report.
    * @param    subs
    *           Parameter substitutions.
    */
   public Log(String text, Variable[] subs)
   {
      super(NAME, "");
      this.text = text;
      this.subs = subs;
   }
   
   /**
    * Execute the directive of the test using the given terminal as the data
    * sink and/or source for the operation.
    *
    * @param    term
    *           The terminal that represents the system under test.
    */
   public void execute(Terminal term)
   {
      String result = text;
      
      if (subs != null)
      {
         result = String.format(text, Variable.resolve(subs));
      }
      
      setDescription(result);
      setStatus(Status.PASSED, null);
   }
}
