/*
** Module   : SftpGet.java
** Abstract : directive to copy files or a directory from the remote system to
**            the local system
**
** Copyright (c) 2009, Golden Code Development Corporation.
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 GES 20090126 Directive to copy files or a directory from the remote
**                  system to the local system.
*/

/*
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU Affero General Public License as
** published by the Free Software Foundation, either version 3 of the
** License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package com.goldencode.harness.test;

import com.goldencode.harness.*;
import com.goldencode.harness.terminal.*;
import com.goldencode.harness.transport.*;

/**
 * Directive to copy files or a directory from the remote system to the local
 * system.
 */
public class SftpGet
extends Report
implements Testable
{
   /** Short name for the activity. */
   private static final String NAME = "SFTP-GET";
   
   /** Format specification for creating a description of this step. */
   private static final String SPEC = "remote = '%s'; local = '%s';";
   
   /** Helper shared by all steps that are part of the same SFTP session. */
   private final SFTPSession sftp;
   
   /** The file or directory specification on the remote system. */
   private final String remote;
   
   /** The file or directory specification on the local system. */
   private final String local;
   
   /**
    * Constructor.
    *
    * @param    sftp
    *           Helper shared by all steps that are part of the same SFTP
    *           session.
    * @param    remote
    *           The file or directory specification on the remote system to
    *           copy from.
    * @param    local
    *           The file or directory target on the local system. 
    */
   public SftpGet(SFTPSession sftp, String remote, String local)
   {
      super(NAME, String.format(SPEC, remote, local));
      this.sftp   = sftp;
      this.remote = remote;
      this.local  = local;
   }
   
   /**
    * Execute the directive of the test using the given terminal as the data
    * sink and/or source for the operation.
    *
    * @param    term
    *           The terminal that represents the system under test.
    */
   public void execute(Terminal term)
   {
      sftp.get(remote, local);
      setStatus(Status.PASSED, null);
   }
}
